R/tauestimate.R
phi1.Rdcomputes phi1 function, internally used to compute the weights for the algorithm
phi1(delta, c2, k2, ese, dis, p)
| delta | positive definite p x p matrix, the estimated covariance of errors |
|---|---|
| c2 | constant for rho_2 function |
| k2 | constant for rho_2 function |
| ese | real positive number, the s-cale of distances |
| dis | vector of distances |
| p | dimension of ambient space |